@@ -2,7 +2,7 @@
 
 #include <stdio.h>
 
-#include <libfprint/fprint.h>
+#include <fprint.h>
 
 struct
 fp_dscv_dev *discover_device(struct fp_dscv_dev **discovered_devs)
