@@ -14,7 +14,7 @@
 #include <err.h>
 #include <util.h>
 
-#include <libfprint/fprint.h>
+#include <fprint.h>
 
 #define FINGER_MIN	1
 #define FINGER_MAX	10
